``pygcam.gcam``
============================

Functions for running the GCAM model. Provides the functionality of the
:ref:`gcam sub-command <gcam>`.

API
---

.. automodule:: pygcam.gcam
   :members:

